// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
/*
 * Add a couple of rows of test data to PN AUX ODF 2nd table
*/

/* General includes */

/* SAS-specific includes */
#include "param.h"
#include "Dal.h"
#include "Tracer.h"

/* Local includes */

int main ()
{
  PROC;
  
  string setname = "a.ds";

  DataSet* set = dataSetServer->open(setname, DataSet::Modify);

  Table * table  = set->table("PNAUX1");
  Table * table2 = set->table("PNAUX2");
  
  /* Add two rows */
  table2->insertRows(0, 2);
  
  /* Populate the columns by relating 
   * the CYCLE and QUADRANT information in the first and 
   * second extensions in the original dataset. */

  Column* cycleCol              = table->column("CYCLE");
  ColumnData* cycleColData      = cycleCol->data();
  int32* cycleData              = cycleColData->int32Data();
  
  Column* quadrantCol           = table->column("QUADRANT");
  ColumnData * quadrantColData  = quadrantCol->data();
  int8*  quadrantData           = quadrantColData->int8Data();

  Column* cycle2Col             = table2->column("CYCLE");
  ColumnData * cycle2ColData    = cycle2Col->data();
  int32*  cycle2Data            = cycle2ColData->int32Data();

  Column* quadrant2Col          = table2->column("QUADRANT");
  ColumnData * quadrant2ColData = quadrant2Col->data();
  int8*  quadrant2Data          = quadrant2ColData->int8Data();
  

  
  /* Access NABOVE column in table */
  Column* nabove2Col              = table2->column("NABOVE"); 
  ColumnData* nabove2ColData      = nabove2Col->data();
  uint16* nabove2Data              = nabove2ColData->uint16Data();

  /* Access NDEFA column in table 2 
  */
  Column* ndefa2Col               = table2->column("NDEFA"); 
  ColumnData* ndefa2ColData       = ndefa2Col->data();
  int16* ndefa2Data               = ndefa2ColData->int16Data();

  /* Access NEPDH column in table 2 
  */
  Column* nepdh2Col               = table2->column("NEPDH"); 
  ColumnData* nepdh2ColData       = nepdh2Col->data();
  uint16* nepdh2Data               = nepdh2ColData->uint16Data();
  

  /* Access NDISCLIN column in table 2 
  */
  Column* ndisclin2Col            = table2->column("NDISCLIN"); 
  ColumnData* ndisclin2ColData    = ndisclin2Col->data();
  int16* ndisclin2Data            = ndisclin2ColData->int16Data();


  /* Access MCOMMODE column in table 2 
  */
  Column* mcommode2Col            = table2->column("MCOMMODE"); 
  ColumnData* mcommode2ColData    = mcommode2Col->data();
  uint16* mcommode2Data           = mcommode2ColData->uint16Data();


  unsigned table1rows = table->rows();
  unsigned table2rows = table2->rows();

  
  /* Initialise the values along all new columns to zero */
  for (unsigned index = 0; index < table2rows; ++index)
    {
      if ( index > table1rows)
	{
	  errstr << " The current index " << index
		 << " Exceed the n. rows in table 1 " << table1rows
		 << Sas::error("TableRowsInconsistent");

	  ALTRETURNV(1);
	}

      cycle2Data[index]    = cycleData[index];
      quadrant2Data[index] = quadrantData[index];

      nabove2Data[index]   = 10;
      ndefa2Data[index]    = 10;
      nepdh2Data[index]    = 10;
      ndisclin2Data[index] = 10;
      mcommode2Data[index] = 10;
    }

  /* Cleanup */
  delete nabove2ColData;
  delete ndefa2ColData;
  delete nepdh2ColData;
  delete ndisclin2ColData;
  delete mcommode2ColData;

  delete cycleColData;
  delete cycle2ColData;
  delete quadrantColData;
  delete quadrant2ColData;

  dataSetServer->close(set);


  RETURN 0;
    
}
